summaryrefslogtreecommitdiff
path: root/bin/nightlybuilds/scoreboard_update.pl
diff options
context:
space:
mode:
Diffstat (limited to 'bin/nightlybuilds/scoreboard_update.pl')
-rwxr-xr-xbin/nightlybuilds/scoreboard_update.pl8
1 files changed, 4 insertions, 4 deletions
diff --git a/bin/nightlybuilds/scoreboard_update.pl b/bin/nightlybuilds/scoreboard_update.pl
index 58f0890980c..086240b39e6 100755
--- a/bin/nightlybuilds/scoreboard_update.pl
+++ b/bin/nightlybuilds/scoreboard_update.pl
@@ -205,15 +205,15 @@ sub load_web_dir ($)
my $ua = LWP::UserAgent->new;
### We are impatient, so don't wait more than 20 seconds for a
### response (the default was 180 seconds)
- $ua->timeout(20);
+ $ua->timeout(10);
my $request = HTTP::Request->new('GET', $address);
my $response = $ua->request($request);
if (!$response->is_success ()) {
- print " ERROR: Could not load web dir\n";
+ warn 'load_web_dir (): Could not load web directory';
return ();
}
@@ -238,7 +238,7 @@ sub load_web_dir ($)
}
}
}
- elsif ($server =~ m/Apache/ || $server =~ m/Boa/) {
+ elsif ($server =~ m/Apache/) {
my @contents = split /\n/, $content;
### Now look for files
@@ -205,15 +205,15 @@ sub load_web_dir ($)
my $ua = LWP::UserAgent->new;
- ### We are impatient, so don't wait more than 20 seconds for a
+ ### We are impatient, so don't wait more than 10 seconds for a
### response (the default was 180 seconds)